@@ -21,7 +21,7 @@ class AEntry(ABC):
             chmod(c.COLLECTION_TITLE, S_IRWXU)
         else:
             # permission handling will be passed down if continued
-            check = input("\nno collection file in directory. create? y/n\n")
+            check = input("\nno collection file in path. create? y/n\n")
             if check != 'y':
                 print("\ncollection file not created")
                 # indicate that the object has not been fully instantiated
